---
name: Feature Request
about: File an issue about adding a feature
title: "[FEAT] "
---


Make sure you've completed the following steps before submitting your issue -- thank you!

1. Check if your feature has already been mentioned / rejected / planned in other issues.
2. If those resources didn't help, consider asking in the [Gitter chat room][] to see if this is interesting / useful to a larger audience and possible to implement reasonably,
4. If you have a useful feature that passes the previous items (or not suitable for chat), please fill in the details below.

[Gitter chat room]: https://gitter.im/pybind/Lobby

*After reading, remove this checklist.*
